@@ -26,6 +26,8 @@
 #'   \item{`likelihood`}{The likelihood used (character string)}
 #'   \item{`link`}{The link function used (character string)}
 #'   \item{`priors`}{A list containing the priors used (as [nma_prior] objects)}
+#'   \item{`basis`}{For `mspline` and `pexp` models, a named list of spline
+#'    bases for each study}
 #'   }
 #'
 #' The `stan_mlnmr` sub-class inherits from `stan_nma`, and differs only in the
@@ -43,19 +45,29 @@ print.stan_nma <- function(x, ...) {
   if (inherits(x$network, "mlnmr_data")) type <- "ML-NMR"
   else type <- "NMA"
   cglue("A {x$trt_effects} effects {type} with a {x$likelihood} likelihood ({x$link} link).")
+  if (x$likelihood %in% c("mspline", "pexp")) {
+    deg <- switch(x$likelihood,
+                  mspline = switch(attr(x$basis[[1]], 'degree'),
+                                   "1" = "Piecewise constant",
+                                   "2" = "Quadratic M-spline",
+                                   "3" = "Cubic M-spline",
+                                   paste('Degree', attr(x$basis[[1]], 'degree'), 'M-spline')),
+                  pexp = 'Piecewise constant')
+    cglue("{deg} baseline hazard with {length(attr(x$basis[[1]], 'knots'))} internal knots.")
+  }
   if (x$consistency != "consistency") {
     if (x$consistency == "nodesplit")
       cglue("An inconsistency model ('{x$consistency}') was fitted, splitting the comparison {x$nodesplit[2]} vs. {x$nodesplit[1]}.")
     else
       cglue("An inconsistency model ('{x$consistency}') was fitted.")
   }
-  if (!is.null(x$regression)) {
-    cglue("Regression model: {rlang::as_label(x$regression)}.")
-    if (!is.null(x$xbar)) {
-      cglue("Centred covariates at the following overall mean values:")
-      print(x$xbar)
-    }
+  if (!is.null(x$regression)) cglue("Regression model: {rlang::as_label(x$regression)}.")
+  if (!is.null(x$aux_regression)) cglue("Auxiliary regression model: {rlang::as_label(x$aux_regression)}.")
+  if ((!is.null(x$regression) || !is.null(x$aux_regression)) && !is.null(x$xbar)) {
+    cglue("Centred covariates at the following overall mean values:")
+    print(x$xbar)
   }
+  if (length(setdiff(x$aux_by, ".study"))) cglue("Stratified baseline hazards by {glue::glue_collapse(x$aux_by, sep = ', ', last = ' and ')}.")
 
   sf <- as.stanfit(x)
   dots <- list(...)
@@ -68,7 +80,14 @@ print.stan_nma <- function(x, ...) {
                                     "theta_bar_cum_agd_arm",
                                     "theta_bar_cum_agd_contrast",
                                     "theta2_bar_cum",
-                                    "mu", "delta"),
+                                    "mu", "delta",
+                                    if (!is.null(x$aux_regression) &&
+                                        length(setdiff(colnames(attr(terms(x$aux_regression), "factor")), ".trt")) > 0) {
+                                      if (x$likelihood %in% c("mspline", "pexp")) NULL else "d_aux"
+                                    } else {
+                                      "beta_aux"
+                                    },
+                                    "scoef"),
                            include = include,
                            use_cache = FALSE,
                            !!! dots,
@@ -238,7 +257,8 @@ plot_prior_posterior <- function(x, ...,
       "trt"[!is.null(x$priors$prior_trt)],
       "het"[!is.null(x$priors$prior_het)],
       "reg"[!is.null(x$priors$prior_reg)],
-      "aux"[!is.null(x$priors$prior_aux)])
+      "aux"[!is.null(x$priors$prior_aux)],
+      "aux_reg"[!is.null(x$priors$prior_aux_reg)])
 
   if (is.null(prior)) {
     prior <- priors_used
@@ -258,13 +278,24 @@ plot_prior_posterior <- function(x, ...,
   if (!is.numeric(ref_line) || !is.null(dim(ref_line)))
     abort("`ref_line` should be a numeric vector.")
 
+  if (x$likelihood %in% c("mspline", "pexp")) n_scoef <- ncol(x$basis[[1]])
+
   # Get prior details
   prior_dat <- vector("list", length(prior))
   for (i in seq_along(prior)) {
-    if (prior[i] %in% c("het", "aux")) trunc <- c(0, Inf)
+    if (prior[i] %in% c("het", "aux") || (prior[i] == "aux_reg" && x$likelihood %in% c("mspline", "pexp"))) trunc <- c(0, Inf)
     else trunc <- NULL
-    prior_dat[[i]] <- get_tidy_prior(x$priors[[paste0("prior_", prior[i])]], trunc = trunc) %>%
-      tibble::add_column(prior = prior[i])
+
+    if (x$likelihood == "gengamma" && prior[i] == "aux") {
+      prior_dat[[i]] <-
+        dplyr::bind_rows(get_tidy_prior(x$priors$prior_aux$sigma, trunc = trunc),
+                         get_tidy_prior(x$priors$prior_aux$k, trunc = trunc)) %>%
+        tibble::add_column(prior = c("aux", "aux2"))
+
+    } else {
+      prior_dat[[i]] <- get_tidy_prior(x$priors[[paste0("prior_", prior[i])]], trunc = trunc) %>%
+        tibble::add_column(prior = prior[i])
+    }
   }
 
   prior_dat <- dplyr::bind_rows(prior_dat) %>%
@@ -273,7 +304,25 @@ plot_prior_posterior <- function(x, ...,
                                            trt = "d",
                                            het = "tau",
                                            reg = "beta",
-                                           aux = switch(x$likelihood, normal = "sigma", ordered = "cc")))
+                                           aux = switch(x$likelihood,
+                                                        normal = "sigma",
+                                                        ordered = "cc",
+                                                        weibull = "shape",
+                                                        gompertz = "shape",
+                                                        `weibull-aft` = "shape",
+                                                        lognormal = "sdlog",
+                                                        loglogistic = "shape",
+                                                        gamma = "shape",
+                                                        gengamma = "sigma",
+                                                        mspline = "sigma",
+                                                        pexp = "sigma"),
+                                           aux2 = switch(x$likelihood,
+                                                         gengamma = "k"),
+                                           aux_reg = switch(x$likelihood,
+                                                            pexp =, mspline = "sigma_beta",
+                                                            weibull =, gompertz =, `weibull-aft` =,
+                                                            lognormal =, loglogistic =, gamma =,
+                                                            gengamma = "beta_aux")))
 
   # Add in omega parameter if node-splitting model, which uses prior_trt
   if (inherits(x, "nma_nodesplit")) {
@@ -446,13 +495,36 @@ plot_prior_posterior <- function(x, ...,
 #'   final estimate (using all `n_int` points) from the estimate using only the
 #'   first \eqn{N_\mathrm{thin}}{N_thin} points.
 #'
+#' # Note for survival models
+#' This function is not supported for survival/time-to-event models. These do
+#' not save cumulative integration points for efficiency reasons (both time and
+#' memory).
+#'
 #' @return A `ggplot` object.
 #' @export
 #'
 #' @examples
 #' ## Plaque psoriasis ML-NMR
-#' @template ex_plaque_psoriasis_mlnmr_example
+#' @template ex_plaque_psoriasis_network
+#' @template ex_plaque_psoriasis_integration
 #' @examples \donttest{
+#' # Fit the ML-NMR model
+#' pso_fit <- nma(pso_net, \dontshow{refresh = if (interactive()) 200 else 0,}
+#'                trt_effects = "fixed",
+#'                link = "probit",
+#'                likelihood = "bernoulli2",
+#'                regression = ~(durnpso + prevsys + bsa + weight + psa)*.trt,
+#'                class_interactions = "common",
+#'                prior_intercept = normal(scale = 10),
+#'                prior_trt = normal(scale = 10),
+#'                prior_reg = normal(scale = 10),
+#'                init_r = 0.1,
+#'                QR = TRUE,
+#'                # Set the thinning factor for saving the cumulative results
+#'                # (This also sets int_check = FALSE)
+#'                int_thin = 8)
+#' pso_fit
+#'
 #' # Plot numerical integration error
 #' plot_integration_error(pso_fit)
 #' }
@@ -464,6 +536,9 @@ plot_integration_error <- function(x, ...,
   if (!inherits(x, "stan_mlnmr"))
     abort("Expecting a `stan_mlnmr` object, created by fitting a ML-NMR model with numerical integration using the `nma()` function.")
 
+  if (inherits(x, "stan_nma_surv"))
+    abort("Not supported for survival models; cumulative integration points are not saved for efficiency reasons.")
+
   if (!rlang::is_bool(show_expected_rate))
     abort("`show_expected_rate` must be a logical value, TRUE or FALSE.")
 
@@ -491,6 +566,8 @@ plot_integration_error <- function(x, ...,
 
   # Get cumulative integration points
   twoparbin <- x$likelihood %in% c("binomial2", "bernoulli2")
+  multi <- x$likelihood == "ordered"
+
   ipars <- c()
   if (has_agd_arm(x$network)) {
     ipars <- c(ipars, "theta_bar_cum_agd_arm")
@@ -501,6 +578,11 @@ plot_integration_error <- function(x, ...,
   if (twoparbin) {
     ipars <- c(ipars, "theta2_bar_cum")
   }
+
+  if (!all(ipars %in% x$stanfit@sim$pars_oi))
+    abort(paste0("Cumulative integration points not saved.\n",
+                 "Re-run model with `int_thin > 0` and `int_check = FALSE` to use this feature."))
+
   int_dat <- as.data.frame(x, pars = ipars) %>%
     dplyr::mutate(.draw = 1:dplyr::n())
 
@@ -508,23 +590,24 @@ plot_integration_error <- function(x, ...,
 
   n_int <- x$network$n_int
 
-  rx <- "^(theta2?)\\[(.+): (.+), ([0-9]+)\\]$"
+  rx <- if (multi) "^(theta2?)\\[(.+): (.+), ([0-9]+), (.+)\\]$" else "^(theta2?)\\[(.+): (.+), ([0-9]+)\\]$"
 
   int_dat <- tidyr::pivot_longer(int_dat, cols = -dplyr::one_of(".draw"),
                                  names_pattern = rx,
-                                 names_to = c("parameter", "study", "treatment", "n_int"),
+                                 names_to = if (multi) c("parameter", "study", "treatment", "n_int", "category") else c("parameter", "study", "treatment", "n_int"),
                                  names_transform = list(n_int = as.integer),
                                  values_to = "value")
 
   int_dat$study <- factor(int_dat$study, levels = levels(x$network$studies))
   int_dat$treatment <- factor(int_dat$treatment, levels = levels(x$network$treatments))
+  if (multi) int_dat$category <- forcats::fct_inorder(factor(int_dat$category))
 
   # Estimate integration error by subtracting final value
   int_dat <- dplyr::left_join(dplyr::filter(int_dat, .data$n_int != max(.data$n_int)),
                               dplyr::filter(int_dat, .data$n_int == max(.data$n_int)) %>%
                                 dplyr::rename(final_value = "value") %>%
                                 dplyr::select(-"n_int"),
-                              by = c("parameter", "study", "treatment", ".draw")) %>%
+                              by = if (multi)  c("parameter", "study", "treatment", "category", ".draw") else c("parameter", "study", "treatment", ".draw")) %>%
     dplyr::mutate(diff = .data$value - .data$final_value)
 
   int_thin <- min(int_dat$n_int)
@@ -595,9 +678,13 @@ plot_integration_error <- function(x, ...,
               args = rlang::dots_list(orientation = orientation, ..., !!! v_args, .homonyms = "first"))
   }
 
-  p <- p +
-    ggplot2::facet_wrap(~ study + treatment) +
-    theme_multinma()
+  if (multi) {
+    p <- p + ggplot2::facet_grid(study + treatment ~ category)
+  } else {
+    p <- p + ggplot2::facet_wrap(~ study + treatment)
+  }
+
+  p <- p + theme_multinma()
 
   return(p)
 }
@@ -692,6 +779,19 @@ as.data.frame.stan_nma <- function(x, ..., pars, include = TRUE) {
   return(as.data.frame(as.matrix(x, ..., pars = pars, include = include)))
 }
 
+#' @rdname as.array.stan_nma
+#' @export
+as_tibble.stan_nma <- function(x, ..., pars, include = TRUE) {
+  return(tibble::as_tibble(as.matrix(x, ..., pars = pars, include = include)))
+}
+
+#' @rdname as.array.stan_nma
+#' @method as.tibble stan_nma
+#' @export
+as.tibble.stan_nma <- function(x, ..., pars, include = TRUE) {
+  return(tibble::as_tibble(as.matrix(x, ..., pars = pars, include = include)))
+}
+
 #' @rdname as.array.stan_nma
 #' @export
 as.matrix.stan_nma <- function(x, ..., pars, include = TRUE) {
